==> corkit-1.0.10.tar.gz: corkit-1.0.10/README.md <==
[![pypi](https://img.shields.io/pypi/v/corkit)](https://pypi.org/project/corkit)
![status](https://img.shields.io/badge/status-beta-red.svg)
[![license](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# CorKit: Coronagraph Science Kit

<img src="https://github.com/Jorgedavyd/corkit/blob/main/docs/source/logo.png"/>

**CorKit** is an open-source Python library designed to streamline the 
retrieval and preprocessing of solar coronagraph data. Its primary aim 
is to democratize access to coronagraph data, enabling a broader community 
of solar scientists to engage in research without the need for proprietary 
software like IDL. It's derived from [Solarsoft](https://www.lmsal.com/solarsoft/):

<img src="https://github.com/Jorgedavyd/corkit/blob/main/docs/examples/c2.png"/>

## Key Features:

1. **Open Source Accessibility**: **CorKit** removes barriers to entry by providing 
free access to solar coronagraph data. Its open-source nature ensures that researchers, 
educators, and enthusiasts can easily retrieve and analyze data without worrying about 
proprietary software licenses.

2. **User-Friendly Interface**: With simple and intuitive methods, **CorKit** makes it 
effortless for users to retrieve and preprocess coronagraph data. This user-centric 
approach allows researchers to focus more on their scientific analysis and less on 
navigating complex data retrieval processes.

3. **Advancing Solar Science**: By empowering researchers with the tools needed to 
preprocess and analyze coronagraph data, **CorKit** contributes to the advancement of 
solar science. Researchers can explore the intricate connections between the Sun and Earth, 
leading to new insights and discoveries.

4. **Community Collaboration**: **CorKit** fosters collaboration and knowledge sharing 
within the solar science community. By providing a common platform for data access and 
preprocessing, the library encourages interdisciplinary collaborations and accelerates 
scientific progress.

## Coronagraph data supported
<img src="https://upload.wikimedia.org/wikipedia/commons/thumb/d/db/Stereo_logo.gif/1200px-Stereo_logo.gif" width="200" height="200" />
<img src="https://lh6.googleusercontent.com/proxy/1sXRF-9df_jeWpUWlyDqUn4ddQ34PIis-2zBpOf46TeKkQPJdNVbLL_ciXXUaS-AZR0Z4tBFqaYSdIZJwuKnhNtIy2pFekckiA" width="200" height="200" />

## Contact  

- [Linkedin](https://www.linkedin.com/in/jorge-david-enciso-mart%C3%ADnez-149977265/)
- [Email](jorged.encyso@gmail.com)
- [GitHub](https://github.com/Jorgedavyd)

==> corkit-1.0.11.tar.gz: corkit-1.0.11/README.md <==
[![pypi](https://img.shields.io/pypi/v/corkit)](https://pypi.org/project/corkit)
![status](https://img.shields.io/badge/status-beta-red.svg)
[![license](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# CorKit: Coronagraph Science Kit

<img src="https://github.com/Jorgedavyd/corkit/raw/main/docs/source/logo.png"/>

**CorKit** is an open-source Python library designed to streamline the 
retrieval and preprocessing of solar coronagraph data. Its primary aim 
is to democratize access to coronagraph data, enabling a broader community 
of solar scientists to engage in research without the need for proprietary 
software like IDL. It's derived from [Solarsoft](https://www.lmsal.com/solarsoft/):

<img src="https://github.com/Jorgedavyd/corkit/raw/main/docs/examples/c2.png"/>

## Key Features:

1. **Open Source Accessibility**: **CorKit** removes barriers to entry by providing 
free access to solar coronagraph data. Its open-source nature ensures that researchers, 
educators, and enthusiasts can easily retrieve and analyze data without worrying about 
proprietary software licenses.

2. **User-Friendly Interface**: With simple and intuitive methods, **CorKit** makes it 
effortless for users to retrieve and preprocess coronagraph data. This user-centric 
approach allows researchers to focus more on their scientific analysis and less on 
navigating complex data retrieval processes.

3. **Advancing Solar Science**: By empowering researchers with the tools needed to 
preprocess and analyze coronagraph data, **CorKit** contributes to the advancement of 
solar science. Researchers can explore the intricate connections between the Sun and Earth, 
leading to new insights and discoveries.

4. **Community Collaboration**: **CorKit** fosters collaboration and knowledge sharing 
within the solar science community. By providing a common platform for data access and 
preprocessing, the library encourages interdisciplinary collaborations and accelerates 
scientific progress.

## Coronagraph data supported
<img src="https://upload.wikimedia.org/wikipedia/commons/thumb/d/db/Stereo_logo.gif/1200px-Stereo_logo.gif" width="200" height="200" />
<img src="https://lh6.googleusercontent.com/proxy/1sXRF-9df_jeWpUWlyDqUn4ddQ34PIis-2zBpOf46TeKkQPJdNVbLL_ciXXUaS-AZR0Z4tBFqaYSdIZJwuKnhNtIy2pFekckiA" width="200" height="200" />

## Contact  

- [Linkedin](https://www.linkedin.com/in/jorge-david-enciso-mart%C3%ADnez-149977265/)
- [Email](jorged.encyso@gmail.com)
- [GitHub](https://github.com/Jorgedavyd)
